<?php
/*
Plugin Name: Category Manager
Plugin URI: http://www.mustakes.com/wp-category-manager/
Description: This plugin makes it easier to manage the addition and removal of a specific category on posts.
Author: Mustansir Golawala
Version: 1.2
Author URI: http://www.mustakes.com/
*/
include_once('categorymanagerfunctions.php');

if ( !class_exists('CategoryManager') ) :

class CategoryManager
{
	var $plugin_url;
	
	var $db_option = 'CategoryManager_options';

	function CategoryManager()
	{
		// Hook into the 'wp_dashboard_setup' action to register our other functions
		add_action('wp_dashboard_setup', array(&$this, 'add_dashboard_widgets') );
		
		$this->plugin_url = trailingslashit(WP_PLUGIN_URL.'/'.dirname(plugin_basename(__FILE__)));
				
		add_action('admin_menu', array(&$this, 'admin_menu'));
		add_action('wp_print_scripts', array(&$this, 'print_scripts'));
		add_action('admin_head', array(&$this, 'print_styles'));
                add_action('wp_ajax_remove_category', 'remove_category');

	}
	
	function add_dashboard_widgets() 
	{
		$options = get_option($this->db_option);
		
		if($options['OnDashboard'] == 'on')
		{
			wp_add_dashboard_widget('cat_manager_dashboard_widget', 'Managing Category - ' . $options['defaultCategory'], array(&$this, 'dashboard_widget_render_function'));	
		}
	} 
	
	function dashboard_widget_render_function() 
	{
		
             $options = get_option($this->db_option);
             $postlist = getPostListForCat($options['defaultCategory']);
             
             if($options['enableDropdown'] == 'on')
             {
             	echo '<div class="catmanselection">';
             	echo $this->getCatSelectBox();
             	echo '</div>';
			 }
             if($postlist)
             {
                 echo '<div id="catmanpostlist" class="list:catmanpost">';
                 renderPosts($postlist);
                 echo '</div>';
             }
             else
             {
             		echo '<div id="catmanpostlist" class="list:catmanpost">';
                    echo '<strong>No posts found</strong>';
                    echo '</div>';

             }
	} 
	
	// Set up default values
	function install() 
	{
		$this->get_options();
	}
	
	// Save/Update the options from the DB
	function get_options()
	{
		$options = array
		(
			'OnDashboard' => 'on',
                        'showConfirm' => 'on',
			'defaultCategory' => '',
                        'enableDropdown' => 'on'
		);
		
		$saved = get_option($this->db_option);
		
		if(!empty($saved))
		{
			foreach($saved as $key => $option)
			{
				$options[$key] = $option;
			}
		}

		if($saved != $options)
		{
			update_option($this->db_option, $options);
		}
		
		return $options;
	}

        

        function getCatSelectBox()
        {
            // Build Category list for the drop down menu
            $options = $this->get_options();
            $catlist = getCatList();

            if($catlist)
            {
               $selectlist = '<select name="defaultCat">';

               foreach($catlist as $cat)
               {
                    if(strcmp($cat->name, $options['defaultCategory'])  == 0)
                    {

                        $selectlist = $selectlist.'<option value="' . $cat->name . '" selected>' . $cat->name . '</option>';
                    }
                    else
                    {
                        $selectlist = $selectlist. '<option value="' . $cat->name . '" >' . $cat->name . '</option>';
                    }
               }
               $selectlist = $selectlist. '</select>';

               return $selectlist;
            }

        }
	
	// handle the settings/options page
	function handle_options()
	{
            $options = $this->get_options();

            if( isset($_POST['submitted']))
            {
                    $options = array();
                    $options['OnDashboard'] = $_POST['ondashboard'];
                    $options['showConfirm'] = $_POST['showConfirm'];
                    $options['defaultCategory'] = $_POST['defaultCat'];
                    $options['enableDropdown'] = $_POST['enableDropdown'];

                    update_option($this->db_option, $options);

                    echo '<div class="updated"><p>Settings Saved</p></div>';
            }

            $ondash = $options['OnDashboard']=='on' ? 'checked' : '';
            $showConfirm = $options['showConfirm']=='on' ? 'checked' : '';
            $defaultCat = $options['defaultCategory'];
            $enableDropdown = $options['enableDropdown']=='on' ? 'checked' : '';;

            $action_url = $_SERVER['REQUEST_URI'];

            $selectlist = $this->getCatSelectBox();

            include('wp-category-manager-settings.php');
			
	}

	
	function admin_menu()
	{
		add_options_page('Category Manager Options', 'Category Manager', 8, basename(__FILE__), array(&$this, 'handle_options'));
	}
	
	function print_scripts()
	{
                $nonce = wp_create_nonce("wp-category-manager");
                $options = $this->get_options();
                
		wp_enqueue_script('jquery');
		wp_enqueue_script('categoryManager_script', $this->plugin_url . 'wp-category-manager.js', array('jquery'));


                // pass parameters to the js
                wp_localize_script('categoryManager_script', 'catmansettings',  array('plugin_url' => $this->plugin_url, 'showConfirm' => $options['showConfirm'],'nonce' => $nonce));
                
	}
	
	function print_styles()
	{
		wp_enqueue_style('categoryManager_css', $this->plugin_url . 'wp-category-manager.css');
		wp_print_styles(array('categoryManager_css'));
	}
}

endif; 

if ( class_exists('CategoryManager') ) :
	
	$categoryManager = new CategoryManager();
	if (isset($categoryManager)) {
		register_activation_hook( __FILE__, array(&$categoryManager, 'install') );
	}
	
endif;


?>
